(function() {

	if (!window['plugins'] || !window['plugins']['AdMob']) {
		return;
	}
	
	// Ad.loadAd = function(publisherId, onCallback, testing) {}
	// Ad.hideAd = function(callback) {}
	// Ad.reloadAd = function(onComplete) {}
	// Ad.preloadInterstitial = function(publisherId, onAdLoaded, isTesting) {}
	// Ad.showInterstitialAd = function() {}
	
	
	var Ad = function() {
		var admob = window.plugins.AdMob;
        var self = this;
        var clbk = null;
        var hasInterstitialView = false;
        var hasInterstitialAd = false;

        self.visible = false;

        var _publisherId = null;
        var _testing = false;

        function callback(evt) {
            if (!evt || !evt.type) return;

            if (evt.type == 'onReceiveAd') {
                self.visible = true;
                if (clbk) {
                    clbk(Game.Ad.MESSAGE_AD_RECEIVED);
                }
            } else if (evt.type == 'onDismissAd') {
                self.visible = false;
            } else if (evt.type == 'onFailedToReceiveAd') {
                self.hideAd();
            }
        }

        function admobError(error, info) {
            console.log("AdMob Error: " + JSON.stringify(error) + (info) ? info : "");
        }

        self.loadAd = function(publisherId, onCallback, testing) {
        	//console.log('loadAd: ' + publisherId + ', testing: ' + testing);
            if (self.visible) {
                if (onCallback) { onCallback(Game.Ad.MESSAGE_AD_RECEIVED) };
                return;
            }
            
            admob.setOptions({
                publisherId: publisherId,
                bannerAtTop: false, // set to true, to put banner at top
                overlap: false, // set to true, to allow banner overlap webview
                offsetTopBar: false, // set to true to avoid ios7 status bar overlap
                isTesting: testing, // receiving test ad
                autoShow: false // auto show interstitial ad when loaded
            });
            
            self.visible = true;
            testing = (testing == undefined) ? false : testing;
            _publisherId = publisherId;
            _testing = testing;
            clbk = onCallback;

            var successCreateBannerView = function() { 
            	//console.log('banner view create, requesting ad...');
            	admob.requestAd({'isTesting': testing}, success, error); 
            };
            var success = function() { admob.showAd(); };
            var error = function(message) { console.log("Error: " + message); };

            var options = {
                'publisherId': publisherId,
                'adSize': admob.AD_SIZE.SMART_BANNER,
                'overlap': true,
                'extras': {
                    'color_bg': '000000',
                    'color_bg_top': '000000',
                    'color_border': '000000'
                }
            }
            admob.createBannerView(options, successCreateBannerView, error);
            
        };

        self.hideAd = function(callback) {
            if (!self.visible) {
                if (callback) { callback(); }
                return;
            }

            admob.destroyBannerView(
            	{},
				function() {
					var evt = document.createEvent("Events");
					evt.initEvent("onDismissAd", true, true);
					document.dispatchEvent(evt);
					if (callback) {
						callback();
					}
				}, function(e) {
					if (callback) {
						callback();
					}
				}
			);
        };

        self.reloadAd = function(onComplete) {
            self.loadAd(_publisherId, onComplete, _testing);
        };
        
        self.preloadInterstitial = function(publisherId, onAdLoaded, isTesting) {
        	//console.log('preloadInterestial');
        	hasInterstitialAd = false;

			admob.createInterstitialView(
				{ 'interstitialAdId': publisherId, 'autoShow': true }, 
				function() {
					hasInterstitialView = true;
					hasInterstitialAd = false;
					//console.log('preloadInterstitial done, loading...');
					loadInterstitialAd(publisherId, onAdLoaded, isTesting);
				}, 
				function(e) {
					// error
					hasInterstitialView = false;
					hasInterstitialAd = false;
					//console.log("Error, can't create interstitial view!\n" + e);
				});
        };
        
        function loadInterstitialAd(publisherId, onAdLoaded, isTesting) {
        	if (!hasInterstitialView) {
        		console.log('No interstitial view created!');
        		return; 
        	}
        	
        	if (isTesting == undefined) {
        		isTesting = false;
        	}
        	
        	admob.requestInterstitialAd(
        		{ 'isTesting': isTesting, 'interstitialAdId': publisherId },
        		function() {
        			//console.log('received interstitial ad');
        			hasInterstitialAd = true;
        			onAdLoaded(true);
        		},
        		function(e) {
        			console.log("Error! Can't request interstitial ad!\n" + e);
        			hasInterstitialAd = false;
        			onAdLoaded(false);
        		}
        	);
        }
        
        self.showInterstitialAd = function() {
        	if (!hasInterstitialView || !hasInterstitialAd) {
        		console.log("Can't showInterstitialAd, it's not loaded!");
        		return;
        	}
        	
        	admob.showInterstitialAd(
        		true, 
        		function() {
        			//console.log('Interstitial Ad shown!');
        		}, 
        		function(e) {
        			//console.log("Can't show interstitial ad!\n" + e);
        		}
        	);
        };
        
        self.hasInterstitialAd = function() {
        	return hasInterstitialView && hasInterstitialAd;
        };
        
        document.addEventListener('onReceiveAd', callback, false);
        document.addEventListener('onFailedToReceiveAd', callback, false);
        document.addEventListener('onPresentAd', callback, false);
        document.addEventListener('onDismissAd', callback, false);
        document.addEventListener('onLeaveToAd', callback, false);

    };


    Game.Ad = new Ad();

    Game.Ad.MESSAGE_AD_RECEIVED = "onReceiveAd";
	


    // Crashes:
    //  https://github.com/floatinghotpot/cordova-plugin-admob

    // TODO: Testing new AdMob Plugin:
    //  https://github.com/aliokan/cordova-plugin-admob/

    // TODO: Activate COPPA stuff
    //  https://developers.google.com/mobile-ads-sdk/docs/admob/additional-controls

    //if (!window.plugins || !window.plugins.AdMob) {
/*    if (!window.admob) {
        return;
    }

    var Ad = function() {

        var self = this;
        var clbk = null;

        self.visible = false;

        var _publisherId = null;
        var _testing = false;

        function callback(evt) {
            if (!evt || !evt.type) return;

            if (evt.type == 'onReceiveAd') {
                self.visible = true;
                if (clbk) {
                    clbk(Game.Ad.MESSAGE_AD_RECEIVED);
                }
            } else if (evt.type == 'onDismissAd') {
                self.visible = false;
            } else if (evt.type == 'onFailedToReceiveAd') {
                self.hideAd();
            }
        }

        function admobError(error, info) {
            console.log("AdMob Error: " + JSON.stringify(error) + (info) ? info : "");
        }

        self.loadAd = function(publisherId, onCallback, testing) {
            if (self.visible) {
                if (onCallback) { onCallback(Game.Ad.MESSAGE_AD_RECEIVED) };
                return;
            }
            self.visible = true;
            testing = (testing == undefined) ? false : testing;
            _publisherId = publisherId;
            _testing = testing;
            clbk = onCallback;

            var successCreateBannerView = function() { admob.requestAd({'isTesting': testing},success,error); };
            var success = function() { };
            var error = function(message) { console.log("Error: " + message); };

            var options = {
                'publisherId': publisherId,
                'adSize': admob.AD_SIZE.SMART_BANNER,
                'extras': {
                    'color_bg': '000000',
                    'color_bg_top': '000000',
                    'color_border': '000000'
                }
            }
            admob.createBannerView(options, successCreateBannerView, error);
        };

        self.hideAd = function(callback) {
            if (!self.visible) {
                if (callback) { callback(); }
                return;
            }

            admob.killAd(function() {
                var evt = document.createEvent("Events");
                evt.initEvent("onDismissAd", true, true);
                document.dispatchEvent(evt);
                if (callback) {
                    callback();
                }
            }, function() {
                console.log('error');
            });
        };

        self.reloadAd = function(onComplete) {
            self.loadAd(_publisherId, onComplete, _testing);
        };

        document.addEventListener('onReceiveAd', callback, false);
        document.addEventListener('onFailedToReceiveAd', callback, false);
        document.addEventListener('onPresentAd', callback, false);
        document.addEventListener('onDismissAd', callback, false);
        document.addEventListener('onLeaveToAd', callback, false);

    };


    Game.Ad = new Ad();

    Game.Ad.MESSAGE_AD_RECEIVED = "onReceiveAd";

*/
})();